from distutils.core import setup

setup(
    name='abxnester',
    version='1.1.0',
    py_modules=['abxnester'],
    author='1821562166',
    author_email='453692941@qq.com',
    url='http://www.headfirstlabs.com',
    description='my first',
    )




"""dfasdfasdfasdfasdasdasdasdfasdfasdfsd
sadfsdafasdfasdf
sadfasdf"""


def print_l(abc):
	for each in abc:
		if isinstance (each,list):
			print_l(each)
		else: print(each)



"""dfefewfasef
safaseegeafae

efaeaesfe"""
